'use strict';

var path = require('path');
var url = require('url');
var child_process = require('child_process');

function _interopNamespaceDefault(e) {
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n.default = e;
    return Object.freeze(n);
}

var child_process__namespace = /*#__PURE__*/_interopNamespaceDefault(child_process);

function spawn(cmd, args) {
    return new Promise((resolve, reject) => {
        const proc = child_process__namespace.spawn(cmd, args);
        const stdout = [];
        const stderr = [];
        proc.stdout.on('data', (data) => stdout.push(data));
        proc.stderr.on('data', (data) => stderr.push(data));
        const getResult = (code) => ({
            code,
            stdout: stdout.join(''),
            stderr: stderr.join(''),
        });
        proc.on('close', (code) => {
            if (code === 0) {
                resolve(getResult(code));
            }
            else {
                reject(getResult(code));
            }
        });
        proc.on('error', (code) => {
            reject(getResult(code));
        });
    });
}

const __dirname$2 = path.dirname(url.fileURLToPath((typeof document === 'undefined' ? new (require('u' + 'rl').URL)('file:' + __filename).href : (document.currentScript && document.currentScript.src || new URL('screenshot-ftw.cjs', document.baseURI).href))));
const activeWindowsCmd$1 = path.join(__dirname$2, 'list-active-windows.exe');
const screenshotCmd$1 = path.join(__dirname$2, 'screenshot-win.exe');
async function getWindows$2() {
    const { stdout } = await spawn(activeWindowsCmd$1, []);
    return JSON.parse(stdout);
}
async function captureWindowByTitle$2(filename, title) {
    await spawn(screenshotCmd$1, ['--window-title', title, filename]);
}
async function captureWindowById$2(filename, windowId) {
    await spawn(screenshotCmd$1, ['--window-id', windowId.toString(), filename]);
}
async function captureScreen$2(filename) {
    await spawn(screenshotCmd$1, [filename]);
}
const api$2 = {
    getWindows: getWindows$2,
    captureWindowByTitle: captureWindowByTitle$2,
    captureWindowById: captureWindowById$2,
    captureScreen: captureScreen$2,
};

const __dirname$1 = path.dirname(url.fileURLToPath((typeof document === 'undefined' ? new (require('u' + 'rl').URL)('file:' + __filename).href : (document.currentScript && document.currentScript.src || new URL('screenshot-ftw.cjs', document.baseURI).href))));
const activeWindowsCmd = path.join(__dirname$1, 'list-active-windows');
const screenshotCmd = 'screencapture';
async function getWindows$1() {
    const { stdout } = await spawn(activeWindowsCmd, ['--open-windows-list']);
    return JSON.parse(stdout);
}
async function captureWindowByTitle$1(filename, title) {
    const windows = await getWindows$1();
    const window = windows.find(window => window.title.includes(title));
    if (!window) {
        throw Error(`no window with title '${title}'`);
    }
    return captureWindowById$1(filename, window.id);
}
async function captureWindowById$1(filename, windowId) {
    await spawn(screenshotCmd, ['-o', '-x', `-l${windowId}`, filename]);
}
async function captureScreen$1(filename) {
    await spawn(screenshotCmd, ['-x', filename]);
}
const api$1 = {
    getWindows: getWindows$1,
    captureWindowByTitle: captureWindowByTitle$1,
    captureWindowById: captureWindowById$1,
    captureScreen: captureScreen$1,
};

async function getWindows() {
    throw new Error('unimplemented');
}
async function captureWindowByTitle(filename, title) {
    throw new Error('unimplemented');
}
async function captureWindowById(filename, windowId) {
    throw new Error('unimplemented');
}
async function captureScreen(filename) {
    await spawn('gnome-screenshot', ['-f', filename]);
}
const api = {
    getWindows,
    captureWindowByTitle,
    captureWindowById,
    captureScreen,
};

function getPlatformAPI() {
    switch (process.platform) {
        case 'win32':
            return api$2;
        case 'darwin':
            return api$1;
        // TODO: support more platforms?
        default:
            return api;
    }
}
const screenshot = getPlatformAPI();

exports.screenshot = screenshot;
//# sourceMappingURL=screenshot-ftw.cjs.map
